@@ -74,6 +74,8 @@ class Payload(object):
         url_args=None,
         custom=None,
         thread_id=None,
+        interruption_level=None,
+        relevance_score=None,
     ):
         self.alert = alert
         self.badge = badge
@@ -84,6 +86,29 @@ class Payload(object):
         self.custom = custom
         self.mutable_content = mutable_content
         self.thread_id = thread_id
+        if interruption_level is not None and interruption_level not in [
+            "passive",
+            "active",
+            "time-sensitive",
+            "critical",
+        ]:
+            raise ValueError(
+                "Invalid value for interruption_level.\n"
+                "Please choice from passive, active, time-sensitive or critical.\n"
+                "https://developer.apple.com/documentation/usernotifications/unnotificationinterruptionlevel"
+            )
+        self.interruption_level = interruption_level
+        if relevance_score is None:
+            self.relevance_score = None
+        elif (isinstance(relevance_score, int) or isinstance(relevance_score, float)) and 0 <= relevance_score <= 1:
+            self.relevance_score = relevance_score
+        else:
+            raise ValueError(
+                "Invalid value for relevance_score.\n"
+                "a value between 0\n"
+                "https://developer.apple.com/documentation/usernotifications/unnotificationcontent/"
+                "3821031-relevancescore"
+            )
 
     def dict(self):
         result = {"aps": {}}
@@ -106,6 +131,10 @@ class Payload(object):
             result["aps"]["category"] = self.category
         if self.url_args is not None:
             result["aps"]["url-args"] = self.url_args
+        if self.interruption_level is not None:
+            result["aps"]["interruption-level"] = self.interruption_level
+        if self.relevance_score is not None:
+            result["aps"]["relevance-score"] = self.relevance_score
         if self.custom is not None:
             result.update(self.custom)
 
